Manual user registration : Python Package Index

#

#### Not Logged In

- Login
- Register
- Lost Login?
- Use OpenID

# Manual user registration

This form allows "traditional" registration (using a password). Users who want to register with their OpenID (e.g. Google or Launchpad account) should follow one of the links to the right.

You can use your PyPI account to log into other services supporting OpenID. You need to first log into PyPI before logging into other services (doing it the other way is prone to phishing attacks). To log in, simply type pypi.python.org into the field asking for an OpenID. Your OpenID is https://pypi.python.org/id/; you can also use this ID directly to log in.

Username: |
Password: |
Confirm: |
Email Address: |
PGP Key ID (optional): | (This identifies a PGP or GPG key)

Please ensure your password is of a reasonable length (>8 characters) and mixes letters, cases and numbers. Please don't use the same password as with other services.

A confirmation email will be sent to the address you nominate above.

Please ensure you will be able to receive email from cheeseshop@python.org (check any "sender confirmation" systems you might be using.)

To complete the registration process, you must visit the link indicated in the email.